@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2002, 2006 IBM Corporation and others.
+ * Copyright (c) 2002, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -153,7 +153,7 @@ public class TreeContentProviderNode implements Comparable<TreeContentProviderNo
 	public void sort() {
 		if (children == null)
 			return;
-		Collections.sort(children);
+		children.sort(null);
 	}
 
 	/**
